@@ -11,8 +11,6 @@ import time
 import traceback
 import uuid
 
-from six import integer_types, string_types, text_type
-
 from logstash_async.constants import constants
 import logstash_async
 
@@ -37,7 +35,7 @@ class LogstashFormatter(logging.Formatter):
             ensure_ascii=True,
             metadata=None,
     ):
-        super(LogstashFormatter, self).__init__()
+        super().__init__()
         self._message_type = message_type
         self._tags = tags if tags is not None else []
         self._extra_prefix = extra_prefix
@@ -113,6 +111,8 @@ class LogstashFormatter(logging.Formatter):
         message.update(record_fields)
         # prepare dynamic extra fields
         extra_fields = self._get_extra_fields(record)
+        # remove all fields to be excluded
+        self._remove_excluded_fields(message, extra_fields)
         # wrap extra fields in configurable namespace
         if self._extra_prefix:
             message[self._extra_prefix] = extra_fields
@@ -132,7 +132,7 @@ class LogstashFormatter(logging.Formatter):
     # ----------------------------------------------------------------------
     def _get_record_fields(self, record):
         def value_repr(value):
-            easy_types = (bool, float, type(None)) + string_types + integer_types
+            easy_types = (type(None), bool, str, int, float)
 
             if isinstance(value, dict):
                 return {k: value_repr(v) for k, v in value.items()}
@@ -150,8 +150,7 @@ class LogstashFormatter(logging.Formatter):
         fields = {}
 
         for key, value in record.__dict__.items():
-            if key not in constants.FORMATTER_RECORD_FIELD_SKIP_LIST:
-                fields[key] = value_repr(value)
+            fields[key] = value_repr(value)
         return fields
 
     # ----------------------------------------------------------------------
@@ -185,6 +184,13 @@ class LogstashFormatter(logging.Formatter):
             stack_trace = ''
         return stack_trace
 
+    # ----------------------------------------------------------------------
+    def _remove_excluded_fields(self, message, extra_fields):
+        for fields in (message, extra_fields):
+            for field_name in list(fields):
+                if field_name in constants.FORMATTER_RECORD_FIELD_SKIP_LIST:
+                    del fields[field_name]
+
     # ----------------------------------------------------------------------
     def _move_extra_record_fields_to_prefix(self, message):
         """
@@ -210,7 +216,7 @@ class DjangoLogstashFormatter(LogstashFormatter):
 
     # ----------------------------------------------------------------------
     def __init__(self, *args, **kwargs):
-        super(DjangoLogstashFormatter, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._django_version = None
         self._fetch_django_version()
 
@@ -221,7 +227,7 @@ class DjangoLogstashFormatter(LogstashFormatter):
 
     # ----------------------------------------------------------------------
     def _get_extra_fields(self, record):
-        extra_fields = super(DjangoLogstashFormatter, self)._get_extra_fields(record)
+        extra_fields = super()._get_extra_fields(record)
 
         if hasattr(record, 'status_code'):
             extra_fields['status_code'] = record.status_code
@@ -238,7 +244,7 @@ class DjangoLogstashFormatter(LogstashFormatter):
             extra_fields['req_remote_address'] = request.META.get('REMOTE_ADDR', '<none>')
             extra_fields['req_host'] = self._try_to_get_host_from_remote(request)
             extra_fields['req_uri'] = request.get_raw_uri()
-            extra_fields['req_user'] = text_type(request_user)
+            extra_fields['req_user'] = str(request_user)
             extra_fields['req_method'] = request.META.get('REQUEST_METHOD', '')
             extra_fields['req_referer'] = request.META.get('HTTP_REFERER', '')
 
@@ -292,7 +298,7 @@ class FlaskLogstashFormatter(LogstashFormatter):
 
     # ----------------------------------------------------------------------
     def __init__(self, *args, **kwargs):
-        super(FlaskLogstashFormatter, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._django_version = None
         self._fetch_flask_version()
 
@@ -305,7 +311,7 @@ class FlaskLogstashFormatter(LogstashFormatter):
     def _get_extra_fields(self, record):
         from flask import request  # pylint: disable=import-error,import-outside-toplevel
 
-        extra_fields = super(FlaskLogstashFormatter, self)._get_extra_fields(record)
+        extra_fields = super()._get_extra_fields(record)
 
         extra_fields['flask_version'] = self._flask_version
         if request:  # request might be unbound in other threads
